# ExpEYES17 PIP Package

entry points : eyes17

maintainer : Jithin B P jithinbp@gmail.com


# Translations
 - translation to French by Georges Khaznadar, <georges.khaznadar at free.fr>,
   Copyright (c) 2019
 - translation to Malayalam by Amal M, <amalmphysics at gmail.com>,
   Copyright (c) 2020
